(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 12.1' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     34367,        753]
NotebookOptionsPosition[     31289,        700]
NotebookOutlinePosition[     31845,        721]
CellTagsIndexPosition[     31802,        718]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["Chapter 7, Section 7.10, Figure 7.12", "Section",ExpressionUUID->"4c583ca5-29ab-42df-b722-130c8619e95e"],

Cell[TextData[{
 "We start by defining ",
 StyleBox["laplace", "Input"],
 ", a procedure to calculate a Laplace coefficient by evaluating an integral \
(see Eq.(6.67))."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"23a1f66f-3303-412c-995e-0cd8bd4183f4"],

Cell["\<\
laplace[ s_, jj_, aa_ ] := 
    If[aa != 0,
       NIntegrate[ N[ (2/Pi)*(Cos[jj*x])/((1-2aa*Cos[x]+aa^2)^s) ], 
               {x, 0, Pi} ],
       0];\
\>", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[1]:=",ExpressionUUID->"12842ddc-be9a-457a-ae8c-0669623c27b0"],

Cell[TextData[{
 "Now we define a function ",
 StyleBox["BrouwerbigAA", "Input"],
 ", a slightly shorter version of the function ",
 StyleBox["Brouwer", "Input"],
 " from ",
 StyleBox["Sect.7.8.nb",
  FontWeight->"Bold"],
 ", that returns the free precession rate for the value ",
 StyleBox["atest", "Input"],
 " of the test particle's semi-major axis.  "
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"2b3480b4-09f3-4ff8-ab9e-88093ccdc961"],

Cell["\<\
BrouwerbigAA[atest_, year_] :=
Module[
 {m = 1/{6025607.0, 408662.0, 328912.0, 3099774.0, 1047.91,
         3500.05, 22970.0, 19360.0},
  a = {0.38710, 0.72333, 1.00002, 1.52364, 5.20248,
       9.56329, 19.29373, 30.27435},
  g = {5.46326, 7.34474, 17.32832, 18.00233, 4.29591,
       27.77406, 2.71931, 0.63332, -19.18225, 51.25222},
  f = {-5.21054, -6.57080, -18.74359, -17.63331, 
       0.00000, -25.73355, -2.90266, -0.67752},
   ntest=360./atest^(3/2)
},
tg = g; tf = f; tb = beta; tga = gamma;
gr = N[g Degree];
fr = N[f Degree];
time = year-1900.;
alphaj    = (atest/a /. {x_ :> 1/x /; x>1});
alphabarj = (atest/a /. {x_ :> 1   /; x>1});
b321 = Map[laplace[3/2, 1, #]&, alphaj];
bigAA =  ntest*((1/4)*(Plus @@ (m*alphaj*alphabarj*b321)));
asbigAA = bigAA*60*60;
N[{atest, asbigAA}]
];\
\>", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[2]:=",ExpressionUUID->"dc51d451-5bfa-4a04-b0e2-966b00cfcebf"],

Cell["\<\
Calculate the value of the free precession rate between 0.1 and 40 AU for \
epoch 1997.\
\>", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"42a8c10d-d498-4489-8574-9571b678f5d6"],

Cell["\<\
precess = 
Table[BrouwerbigAA[avalue, 1997], {avalue, 0.1, 40, 0.1}];\
\>", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[3]:=",ExpressionUUID->"71aafb30-1a9d-43a7-890c-c7e98dd0e484"],

Cell["Plot the resulting values in the range 4 to 40 AU.", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"ea41f3db-d17e-4ca9-9c9d-4b458e80023d"],

Cell[CellGroupData[{

Cell["\<\
pout =
ListPlot[precess, PlotJoined->True, 
Frame->True, PlotRange->{{4,40},{0,60}}]\
\>", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[4]:=",ExpressionUUID->"a97ca0a4-743e-4e94-b155-a147f337f81e"],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.007333333333333334], 
     AbsoluteThickness[1.6], 
     LineBox[{{0.1, 0.6229797026696402}, {0.2, 2.013032394665853}, {
      0.30000000000000004`, 5.840682433316474}, {0.34234439325543925`, 60.}}],
      LineBox[{{0.4613351220744746, 60.}, {0.5, 13.513566773169684`}, {0.6, 
      34.086553413242996`}, {0.6033928852519468, 60.}}], 
     LineBox[{{1.1295847011622868`, 60.}, {1.2000000000000002`, 
      27.441046170569955`}, {1.3000000000000003`, 20.631440575836212`}, {
      1.4000000000000001`, 22.6776053475962}, {1.4263249256150738`, 60.}}], 
     LineBox[{{1.5792350035261062`, 60.}, {1.6, 32.6260347709744}, {
      1.7000000000000002`, 22.734397535729062`}, {1.8000000000000003`, 
      23.08114903542798}, {1.9000000000000001`, 24.80557470428947}, {2., 
      27.101433814777423`}, {2.1, 29.800889402507703`}, {2.2, 
      32.8682711121765}, {2.3000000000000003`, 36.3126483232872}, {
      2.4000000000000004`, 40.16556181640701}, {2.5000000000000004`, 
      44.47455396392125}, {2.6, 49.30194734486096}, {2.7, 
      54.726014360349225`}, {2.786208546492953, 60.}}], 
     LineBox[CompressedData["
1:eJw91HlIFGEYx/FdSzOsQJNStkN3V2ePmdmZWTUt1J9ZHh0iUlq2WQpbVJao
GQZ5VFJahJZUKmVrpx0W1ZIVHVZklGeiBRUGarlmSIf0R6LW2rM9MLz/zHzm
+74D45uWkWB2kslkMX8v+/q6vq+147U/ZBMTRysDl67yOUcyl8M4MQzMYbY7
ZfJYbN5kHwYWV0tUT18Uqirtw+DNRt7qN30pWprtw2Dw4kd2dEckeRq4Jlc/
iZcvJk+DM9Zjb148AHkaxJgUTFNQOHkaKD6VVewRQsnToHjm0FBeyiLytHDy
imiYdD+EPC2yttfFJocGk6dF7WjC/Ju9QeRpMXCmeuR7bSB5WtRfPj/DUhJA
ng7PTCvfP9xnJE+HcV9X7u5RiTwdtq1tdVttFcnTQVa04u0Fm0CeDuLsD70j
rECeHtW156RH4zx5euz0ebxhWgNHnh5PvI/vtlSw5OmBezvP5h/Uk6dHXdnq
4f5DOvJYfDj9ezihRksei47Sb+HmlxryWCTa1gcMyTXksfB8kZvfE8uQx6Kf
3WxaY3F8Zw4e3o1FRZP9yePgZNpaVZ/jRx4HL/8tc00/1eRx6EyNaxneoyaP
Q1bOq2yFh5o8Hlr3YI/CWyryeOBobIZtvYo8HpFfZjkLniryeIQ9bU6I6VKS
x+N65KGKkBoleQY8OHt/ijpXSZ4BJ0yWXRHJSvIM+FXuc7U/WkmeAXxAQdLh
CIdnwBW579dn0Q5PQJablB6/ju73FuB+Q7F3bp4SARO+gJPJCxUrr9PzKwQU
uP5wwTfH+wRUXssfq1migtzOFQqYnOszlFvn2I8AD11JSjCn/ufdFuDbMDv+
XaPjvAS0S5nLx/PofD8L6Iwe9vZK8v/nyUToqtrLTyUx1CfieXdb6qoDGuoT
Eb9pzHp3UEt9ItLS+o27j+mpT0SlS+k6YzFHfSIWtAWmZ3cbqE9Eu2fQMvdE
kfrEv/1N2S1TjNQnonRqT0i3VyD1ibhkU0fFXVhAfRLqzF2tWzsXUp8E80Cv
38XuMOqTMF9pdba6LaY+CVNtbdXTC5ZSnwQVk5F4nl+G/fPCEpEj/f/f/AHK
1rb5
      "]], LineBox[CompressedData["
1:eJw91HtQVHUUB/BFaqLYYnd5LiuPRQTZgYDdu4977y58eYQDOaZUZiEowa4k
KIyGBaJiYZvSLOMygODoRExBiQksSDo+JppQDNBAnWCCiSAlJgpJ5RFKEIfO
zG9+f93vfM7cc37yt7MTjSsEAkHywlm8t1ySsAU+DAT/1XowqsViIO2yvmn1
jkd350KtY5AUVpJ20hqL7abFYjDf/stgkCoKdoufFTJwee2O8vsoA6oqF4tB
wo9nbk9GsEt5NgYr2yK54hc0S3mdDEyvtNTU5auW8u4yKJePt1Ynhy/lCdQI
krl9aseGLuVJ1WATzfm+a4PJp8aeidNM7LUg8qlxRXhjk/KLQPKp8eCAsPrO
jdXkU2O/96pnftP6k08NzcnPPxzu9SOfGmVdGx7nnZCTT42aYymbJ82+5FPD
7+f7Wc2BPuTTwOyriMnL9SKfBm2izKG++zLyLfTp9/T+i+We5NPgpsPZDQ5b
peTT4FZ/2PS7cR7k06DpUlV0erw7+TSw9GU+/i7djXwanGIFQw/LXMmnQcXX
fxku9ruQT4PGif5tinAX8mlhyp4drahwJp8W4l3daeVCZ/JpIUnruT1qkZBP
i6aWAVuBl4R8Wsw9td49vVVMPi2ik3eP30wSk0+L0LM/PBQ9JyafFj0tHplH
vxWRT4vZWhN3/pCIfFpk/SNtDE4QkU+HU67ZJYc9ReTTwevCi0OjI07k0+F8
hHgmp8aJfDood07Z9DlO5NMh9aOApicJTuTToeZcZfUhlRP5dGhuL329Nojy
bDq8emA3kxFCeZ06TI8eneqJoLy7OlzeMXBBmEJ5AhZPftq6ZWMx5UlZnHur
KPhB+7KPhVzamdfgQP2uY/Hno946i5r6NbEYSdoJ4w7qt3BhD0ZS20prqd9K
FrdYx7Ej4yLysajM6I7r0IvJx6Lrni3gXpmYfCw8FOJBywz9DwGH3CK+oChD
Qj4Om2snBHXDEvJxCCz+RjGT6Uw+Dp/txdyJFTQvJg6Jfwx7DdbRvBRyiBC3
xhu2uZKPw7FJ+7ldiuX546CcEzW+86w7+TiIeiDMmXcnH4dSu6pkbycp+Xgk
rD4o28d7ko9Hv3+J2PHj5f3gkbXRLXJseiX5eMTOmuvHrN7k49FRPrxnIMSX
fDxE89eUjiFy8vFocThutHt5eX955Jxxl5V8sop8PE7njzz/wZQ/+XgMpMxE
jVoDyKfHe3UtMabta8inhy0u6/qXBxXk00PhI5y0/z2YfHpc7vXL55tDyaeH
+f2Gq2/so/eqUA+Pv/uYaaOKfHqkpll77OvV5NPjkUoZZDLqyKdHkf3eTVlN
PPn0OJIYk2u5Ekk+A2Qd0181GKPJZ4Cl/vqvsuMvkc8A81U5t+ZCPKRyc3jY
WsP/7/e/1DFD4Q==
      "]], LineBox[CompressedData["
1:eJwt1GtQlFUcx/FdkUAkWVChpY0BFmgHM9kQsJR5fud5gAx3SBBnWm4RuTDJ
BKggIJc2zW7ogAkSK2ZBblMDGBKWxC3SxoBE6DY6gvKCy8JyWRYQQqHFc/4z
zzzzzJzzPXM+Lx6PpPQozRqRSKS2PKvvE6ljtS6hHERPJgK3ui2j4pBdVbPt
qrMKKcmrw+GoI399MuZViFeXaTmE8HUre34WoKtYHQ4b5n2VyUPAdn/LNHDY
MmT/aWxoMO11c3g7TtdYf/5l2hvmcPL4PruMikB2LhDkbTRMPbMdf6wutweu
DG8yFC8raV8K+GpNnt8F+NH9PoAx7Q29e/xWep4/8H1NbHhsky9YDuW603JF
hoL2VECO7YBQle5De2qgMUHuOlzjxe4HKCvuahLc5LR3BPitrGeOa/agPa0l
OGp1zUfrTnungNJL6a1lv7ux+wM7X4/zLu6S0Z4emCrtyOhfdmUegOlA04Aq
Xkp77YC4pe7e+UEX2usGXnrlknjvR860dwd4Pumt+rPhm5kXYDv7Y46rYhPt
mQGp5HKN3XMbmR9B3WtB28Z9nJif5Xspt7BUcGR+BCczwzRehyTMj+C6p+zM
SKwD8yMYMXwdLTM9zfwIon1T3fdftGd+BDdzY6R7DqxnfgTN/f++uxBsx/wI
+vSne4p91zE/guqWW/5ZClvmR/BZ3oPqoEAb5kdQ+cWZ6aKop5gfwWBGmdfu
fGvmR/CXU2n5m1fWMj+CpiLXT+6brZgfQUl274tGzor5EQQ0/+nVWraG+RE4
KG4rv5wVMz8CF/N01ESsmPkR6EdTrR26RMyPx7Ek5Y08ImJ+PD42PD6cWrDC
UT8e75uTnM5+sMxRPx4X4gKqdeWPOerHQ1py42hb4yOO+vHYnEb2RQwscdTP
sv9h28pXkiXaU1v65woWPFT/0V4yj4M1mjBSskh7R3gU6uuyCu4t0J6Wx4Cu
/5t4vwXaO8VjR6K49VDRQ9qr4CEOT/g8cmKe9vQ8vOVu71Tun6e9Bh47O4dc
Fn6do712HpXGzB8kO+Zor5vHI03dfHn9LO3d4aGy1nWG+M3S3jAP+bOykb4G
M+2ZeSjloWlrdplpTyTgwdiuc+U3Z2jPXkBqlkEdo55hfgK2Sov8nCdNzE9A
buaFrooPTcxPgE1w4t2rnibuyf8FApyt8/tIxzTzEzDsFNbiqJlmfgLUtf7r
ROunmZ+AyDFl6+2UKeYnwJDfMLe3bZL2tAIOy3I2QDbJ/AR42CgWEwsnmJ8A
iUay9tiQkfkJ+KcnpSo60sj8BAxuHApq+WWc9toF/N27e/R44DjzE9DZc+Jg
9uUx5ifg4syW+2kvjDE/AVUBi99ytQbmJyDvPbuIDqWB9kQhiPH8SdV7bZT7
HyjyT+E=
      "]]}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{4., 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{4, 40}, {0, 60}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0, 0}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.811396302386269*^9},
 CellLabel->"Out[4]=",ExpressionUUID->"6765730f-34c8-4286-9d38-54f0248324d5"]
}, Open  ]],

Cell["\<\
Set the secular eigenfrequencies of the Brouwer and van Woerkom system.\
\>", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"833daf2b-3d5a-4992-91e2-b97366f85591"],

Cell["\<\
gg = {5.46326, 7.34474, 17.32832, 18.00233, 4.29591,
       27.77406, 2.71931, 0.63332, -19.18225, 51.25222};
ff = {-5.21054, -6.57080, -18.74359, -17.63331, 
       0.00000, -25.73355, -2.90266, -0.67752};\
\>", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[5]:=",ExpressionUUID->"5c22d214-655a-445d-916a-6b3da546b41f"],

Cell["\<\
Create a graphics object of lines denoting the secular eigenfrequencies.\
\>", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"b807715f-59bb-4418-ba6a-d9752e9c790e"],

Cell["\<\
gout = Graphics[Map[Line[{{4,#},{40,#}}]&, gg]];
fout = Graphics[
Join[{Dashing[{0.01, 0.01}]},
     Map[Line[{{4,#},{40,#}}]&, -ff]]];\
\>", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[7]:=",ExpressionUUID->"6f9bce32-af29-42b1-a369-bec1da83d2db"],

Cell["Display the plot with the eigenfrequencies.", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"55fb4b69-e04b-43fe-9a16-642eea83637e"],

Cell[CellGroupData[{

Cell["Show[pout, gout, fout]", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[9]:=",ExpressionUUID->"c27abf52-0b6f-496b-8207-d8b6a3bd63d1"],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.007333333333333334],
       AbsoluteThickness[1.6], 
      LineBox[{{0.1, 0.6229797026696402}, {0.2, 2.013032394665853}, {
       0.30000000000000004`, 5.840682433316474}, {0.34234439325543925`, 
       60.}}], LineBox[{{0.4613351220744746, 60.}, {0.5, 
       13.513566773169684`}, {0.6, 34.086553413242996`}, {0.6033928852519468, 
       60.}}], LineBox[{{1.1295847011622868`, 60.}, {1.2000000000000002`, 
       27.441046170569955`}, {1.3000000000000003`, 20.631440575836212`}, {
       1.4000000000000001`, 22.6776053475962}, {1.4263249256150738`, 60.}}], 
      LineBox[{{1.5792350035261062`, 60.}, {1.6, 32.6260347709744}, {
       1.7000000000000002`, 22.734397535729062`}, {1.8000000000000003`, 
       23.08114903542798}, {1.9000000000000001`, 24.80557470428947}, {2., 
       27.101433814777423`}, {2.1, 29.800889402507703`}, {2.2, 
       32.8682711121765}, {2.3000000000000003`, 36.3126483232872}, {
       2.4000000000000004`, 40.16556181640701}, {2.5000000000000004`, 
       44.47455396392125}, {2.6, 49.30194734486096}, {2.7, 
       54.726014360349225`}, {2.786208546492953, 60.}}], 
      LineBox[CompressedData["
1:eJw91HlIFGEYx/FdSzOsQJNStkN3V2ePmdmZWTUt1J9ZHh0iUlq2WQpbVJao
GQZ5VFJahJZUKmVrpx0W1ZIVHVZklGeiBRUGarlmSIf0R6LW2rM9MLz/zHzm
+74D45uWkWB2kslkMX8v+/q6vq+147U/ZBMTRysDl67yOUcyl8M4MQzMYbY7
ZfJYbN5kHwYWV0tUT18Uqirtw+DNRt7qN30pWprtw2Dw4kd2dEckeRq4Jlc/
iZcvJk+DM9Zjb148AHkaxJgUTFNQOHkaKD6VVewRQsnToHjm0FBeyiLytHDy
imiYdD+EPC2yttfFJocGk6dF7WjC/Ju9QeRpMXCmeuR7bSB5WtRfPj/DUhJA
ng7PTCvfP9xnJE+HcV9X7u5RiTwdtq1tdVttFcnTQVa04u0Fm0CeDuLsD70j
rECeHtW156RH4zx5euz0ebxhWgNHnh5PvI/vtlSw5OmBezvP5h/Uk6dHXdnq
4f5DOvJYfDj9ezihRksei47Sb+HmlxryWCTa1gcMyTXksfB8kZvfE8uQx6Kf
3WxaY3F8Zw4e3o1FRZP9yePgZNpaVZ/jRx4HL/8tc00/1eRx6EyNaxneoyaP
Q1bOq2yFh5o8Hlr3YI/CWyryeOBobIZtvYo8HpFfZjkLniryeIQ9bU6I6VKS
x+N65KGKkBoleQY8OHt/ijpXSZ4BJ0yWXRHJSvIM+FXuc7U/WkmeAXxAQdLh
CIdnwBW579dn0Q5PQJablB6/ju73FuB+Q7F3bp4SARO+gJPJCxUrr9PzKwQU
uP5wwTfH+wRUXssfq1migtzOFQqYnOszlFvn2I8AD11JSjCn/ufdFuDbMDv+
XaPjvAS0S5nLx/PofD8L6Iwe9vZK8v/nyUToqtrLTyUx1CfieXdb6qoDGuoT
Eb9pzHp3UEt9ItLS+o27j+mpT0SlS+k6YzFHfSIWtAWmZ3cbqE9Eu2fQMvdE
kfrEv/1N2S1TjNQnonRqT0i3VyD1ibhkU0fFXVhAfRLqzF2tWzsXUp8E80Cv
38XuMOqTMF9pdba6LaY+CVNtbdXTC5ZSnwQVk5F4nl+G/fPCEpEj/f/f/AHK
1rb5
       "]], LineBox[CompressedData["
1:eJw91HtQVHUUB/BFaqLYYnd5LiuPRQTZgYDdu4977y58eYQDOaZUZiEowa4k
KIyGBaJiYZvSLOMygODoRExBiQksSDo+JppQDNBAnWCCiSAlJgpJ5RFKEIfO
zG9+f93vfM7cc37yt7MTjSsEAkHywlm8t1ySsAU+DAT/1XowqsViIO2yvmn1
jkd350KtY5AUVpJ20hqL7abFYjDf/stgkCoKdoufFTJwee2O8vsoA6oqF4tB
wo9nbk9GsEt5NgYr2yK54hc0S3mdDEyvtNTU5auW8u4yKJePt1Ynhy/lCdQI
krl9aseGLuVJ1WATzfm+a4PJp8aeidNM7LUg8qlxRXhjk/KLQPKp8eCAsPrO
jdXkU2O/96pnftP6k08NzcnPPxzu9SOfGmVdGx7nnZCTT42aYymbJ82+5FPD
7+f7Wc2BPuTTwOyriMnL9SKfBm2izKG++zLyLfTp9/T+i+We5NPgpsPZDQ5b
peTT4FZ/2PS7cR7k06DpUlV0erw7+TSw9GU+/i7djXwanGIFQw/LXMmnQcXX
fxku9ruQT4PGif5tinAX8mlhyp4drahwJp8W4l3daeVCZ/JpIUnruT1qkZBP
i6aWAVuBl4R8Wsw9td49vVVMPi2ik3eP30wSk0+L0LM/PBQ9JyafFj0tHplH
vxWRT4vZWhN3/pCIfFpk/SNtDE4QkU+HU67ZJYc9ReTTwevCi0OjI07k0+F8
hHgmp8aJfDood07Z9DlO5NMh9aOApicJTuTToeZcZfUhlRP5dGhuL329Nojy
bDq8emA3kxFCeZ06TI8eneqJoLy7OlzeMXBBmEJ5AhZPftq6ZWMx5UlZnHur
KPhB+7KPhVzamdfgQP2uY/Hno946i5r6NbEYSdoJ4w7qt3BhD0ZS20prqd9K
FrdYx7Ej4yLysajM6I7r0IvJx6Lrni3gXpmYfCw8FOJBywz9DwGH3CK+oChD
Qj4Om2snBHXDEvJxCCz+RjGT6Uw+Dp/txdyJFTQvJg6Jfwx7DdbRvBRyiBC3
xhu2uZKPw7FJ+7ldiuX546CcEzW+86w7+TiIeiDMmXcnH4dSu6pkbycp+Xgk
rD4o28d7ko9Hv3+J2PHj5f3gkbXRLXJseiX5eMTOmuvHrN7k49FRPrxnIMSX
fDxE89eUjiFy8vFocThutHt5eX955Jxxl5V8sop8PE7njzz/wZQ/+XgMpMxE
jVoDyKfHe3UtMabta8inhy0u6/qXBxXk00PhI5y0/z2YfHpc7vXL55tDyaeH
+f2Gq2/so/eqUA+Pv/uYaaOKfHqkpll77OvV5NPjkUoZZDLqyKdHkf3eTVlN
PPn0OJIYk2u5Ekk+A2Qd0181GKPJZ4Cl/vqvsuMvkc8A81U5t+ZCPKRyc3jY
WsP/7/e/1DFD4Q==
       "]], LineBox[CompressedData["
1:eJwt1GtQlFUcx/FdkUAkWVChpY0BFmgHM9kQsJR5fud5gAx3SBBnWm4RuTDJ
BKggIJc2zW7ogAkSK2ZBblMDGBKWxC3SxoBE6DY6gvKCy8JyWRYQQqHFc/4z
zzzzzJzzPXM+Lx6PpPQozRqRSKS2PKvvE6ljtS6hHERPJgK3ui2j4pBdVbPt
qrMKKcmrw+GoI399MuZViFeXaTmE8HUre34WoKtYHQ4b5n2VyUPAdn/LNHDY
MmT/aWxoMO11c3g7TtdYf/5l2hvmcPL4PruMikB2LhDkbTRMPbMdf6wutweu
DG8yFC8raV8K+GpNnt8F+NH9PoAx7Q29e/xWep4/8H1NbHhsky9YDuW603JF
hoL2VECO7YBQle5De2qgMUHuOlzjxe4HKCvuahLc5LR3BPitrGeOa/agPa0l
OGp1zUfrTnungNJL6a1lv7ux+wM7X4/zLu6S0Z4emCrtyOhfdmUegOlA04Aq
Xkp77YC4pe7e+UEX2usGXnrlknjvR860dwd4Pumt+rPhm5kXYDv7Y46rYhPt
mQGp5HKN3XMbmR9B3WtB28Z9nJif5Xspt7BUcGR+BCczwzRehyTMj+C6p+zM
SKwD8yMYMXwdLTM9zfwIon1T3fdftGd+BDdzY6R7DqxnfgTN/f++uxBsx/wI
+vSne4p91zE/guqWW/5ZClvmR/BZ3oPqoEAb5kdQ+cWZ6aKop5gfwWBGmdfu
fGvmR/CXU2n5m1fWMj+CpiLXT+6brZgfQUl274tGzor5EQQ0/+nVWraG+RE4
KG4rv5wVMz8CF/N01ESsmPkR6EdTrR26RMyPx7Ek5Y08ImJ+PD42PD6cWrDC
UT8e75uTnM5+sMxRPx4X4gKqdeWPOerHQ1py42hb4yOO+vHYnEb2RQwscdTP
sv9h28pXkiXaU1v65woWPFT/0V4yj4M1mjBSskh7R3gU6uuyCu4t0J6Wx4Cu
/5t4vwXaO8VjR6K49VDRQ9qr4CEOT/g8cmKe9vQ8vOVu71Tun6e9Bh47O4dc
Fn6do712HpXGzB8kO+Zor5vHI03dfHn9LO3d4aGy1nWG+M3S3jAP+bOykb4G
M+2ZeSjloWlrdplpTyTgwdiuc+U3Z2jPXkBqlkEdo55hfgK2Sov8nCdNzE9A
buaFrooPTcxPgE1w4t2rnibuyf8FApyt8/tIxzTzEzDsFNbiqJlmfgLUtf7r
ROunmZ+AyDFl6+2UKeYnwJDfMLe3bZL2tAIOy3I2QDbJ/AR42CgWEwsnmJ8A
iUay9tiQkfkJ+KcnpSo60sj8BAxuHApq+WWc9toF/N27e/R44DjzE9DZc+Jg
9uUx5ifg4syW+2kvjDE/AVUBi99ytQbmJyDvPbuIDqWB9kQhiPH8SdV7bZT7
HyjyT+E=
       "]]}}, {{}, {}}}, {LineBox[{{4, 5.46326}, {40, 5.46326}}], 
    LineBox[{{4, 7.34474}, {40, 7.34474}}], 
    LineBox[{{4, 17.32832}, {40, 17.32832}}], 
    LineBox[{{4, 18.00233}, {40, 18.00233}}], 
    LineBox[{{4, 4.29591}, {40, 4.29591}}], 
    LineBox[{{4, 27.77406}, {40, 27.77406}}], 
    LineBox[{{4, 2.71931}, {40, 2.71931}}], 
    LineBox[{{4, 0.63332}, {40, 0.63332}}], 
    LineBox[{{4, -19.18225}, {40, -19.18225}}], 
    LineBox[{{4, 51.25222}, {40, 51.25222}}]}, 
   {Dashing[{0.01, 0.01}], LineBox[{{4, 5.21054}, {40, 5.21054}}], 
    LineBox[{{4, 6.5708}, {40, 6.5708}}], 
    LineBox[{{4, 18.74359}, {40, 18.74359}}], 
    LineBox[{{4, 17.63331}, {40, 17.63331}}], LineBox[{{4, 0.}, {40, 0.}}], 
    LineBox[{{4, 25.73355}, {40, 25.73355}}], 
    LineBox[{{4, 2.90266}, {40, 2.90266}}], 
    LineBox[{{4, 0.67752}, {40, 0.67752}}]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{4., 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{4, 40}, {0, 60}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0, 0}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.811396302417268*^9},
 CellLabel->"Out[9]=",ExpressionUUID->"b1fd5258-ac05-493d-8173-144cd80a1f2d"]
}, Open  ]],

Cell["\<\
Now consider the inner part of the solar system.  Calculate the free \
precession rate between 0.1 and 4 AU.\
\>", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"faf53744-1524-4491-862a-40ad8ebaf6ed"],

Cell["\<\
precessinner = 
Table[BrouwerbigAA[avalue, 1997], {avalue, 0.1, 4, 0.01}];\
\>", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[10]:=",ExpressionUUID->"222c82f2-9444-4f13-bece-f7294e530306"],

Cell["Plot the rate as a function of semi-major axis.", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"40d611ae-cfdb-440a-8da0-66352d0283e2"],

Cell[CellGroupData[{

Cell["\<\
pin = 
ListPlot[precessinner, PlotJoined->True, 
Frame->True, PlotRange->{{0,4},{0,60}}]\
\>", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[11]:=",ExpressionUUID->"261f2a88-2d15-4be8-ad63-6dc582256655"],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.007333333333333334], 
     AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQPWsmCOy07zFTVCx+/9heM6b/0FeNPfZrJty9KKr3
3H6nXOvrwB377H9d3t7Av/SV/ZICW67riw/Y+/Ws2sEe/s7+TeAOoIqD9h4d
Qt0HlT/amxiDwGF76UVKGxttP9tXi6xzf1h1xP7H9TtCs6u/2h/+qgG04ag9
Z/XdW7MefrcHGgY08bj9vweLqj8W/7IPAhkXeMJ+cqnKUgOLv/YQ9520/8GW
vmuDFIPDoyqQgafsPz6wfmm3i9EB4t4z9qdNrFj6G5gdCkHOKzhrvyiN455V
KasDxP3n7C+FN3imLWJ3YACDC/YLHPcW3RPlcoD454L95O0bdt55xOPg8RBk
wUX7L6UtbQVCAg4Q/1201zgiv92OSchhwiGQBy7Z850tP3o/XsQB4t/L9h9X
it6+HSPuAPbO9cv2yXWlOeU+0g4Q/1+x/3f/tcznRAUHeZBz5K7ay3MvW9BT
pOIANu7QVXvzZDvdpYLaDmlgcM3e7843t2krjR0g4XPdvqfz6O2sXQ4OzRd1
OC/nXLeH+MPPAQC9utIr
      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQfTBxdUO/yi17BjDwc7Djur64wPaW/eqKw8c50twd
HlWJrHN/eMs+w60rkdXPyqHtdeAOudbb9j3vcw80rjFy0IrpP/RV4479b/Hw
fqVCPYdzZ0Dgjr1qw7rv28W0HQpsQQbetb//fbPbsU5NB5BpVSL37Ld1M0RG
cGo6AA0DmnjPvuFHRpW2paYD2LiY+/ZlARv27X2l6QBx1wP792pxlp/YtB2C
wBoe2O970X5drkXHYQnYggf2dmcsrIsS9Ry+aYBMeGCftebUkoogAwePh2AP
2L/b+DG1dK2hw6yZIPDQPrj9craFt7HDG5B3Xj+0N6uqX5BoaQr1/yP7tztF
z7zuMncAO6f/kf22rVe2WURZOUCMe2TfUC1XEXTG1sEYDB7bG8xbrifC7ejQ
Cg6fx/a8x9YxzD7k7AAyjev6Y3smcf/1mu7uDppgDz6xb2vIWiH1xduhNCw4
Vcz5CTz8AaBztKU=
      "]], 
     LineBox[{{0.8411725519888572, 60.}, {0.85, 58.869482463564125`}, {0.86, 
      59.34626183294532}, {0.8629617850360661, 60.}}], LineBox[CompressedData["
1:eJw9kl9IU2EYxudYN8YMwUkWLboZ0zUKdo6bq/m+M3KGGE2pIGxFsQVFuVYw
OUUQsRlpM8zI04Qca9FFTgIjSxikUTdptYusIWH2b7FheP4tFkH7xkcPfHx3
P56H37vlWE+nV61SqQylR/5Qj2c//3YVVOXsxbx7Sh/KrYJHG9mkbW9HXdL1
masRwNDVt91d14bNlQtxv0OAYP/IoufmbjzhIxEglTn9t+X6LrwxIxu7BwUQ
89loV9aJT0s095QAvzacCyQiiMtcTYkowAP+/Zh/qRnXElylCKPp55EOtQMZ
C4kIqbuffFn/Djw8SIAiDP2um7yot2M4RwqKYLw0n/ComnCC1EuKEKvfumSp
suEHglsQoXV23zOv04oV5V0SzIc9G6eHG7G+mwAlmDNanVWaRuwkc90S/Ih+
j9cOsHiB1OMkSEWrp50NLN4juLgEE6eYhtuLDM69JpEgfGul9n6MQcVIgBJo
/+SPcL0MbiZz9TI433F2/iiDbaSeS4Zccf21NYcYPEtwfhkyhgq2w8vgHZ5E
BpPpTTF2hcFZuQwER/ULi/oJQ33IUEyvW+5Vs9SHAj9HfUOXT7LUhwLfxpuC
CZmlPhSwhVz9wfFG6kMBs/joJTNmpT4USJ8JHBj4YqM+FDi+zZQc4e3URwEe
m4c1UNxJfRQgmL+q01iQ+iiALrOnj3/VQn0UwDJz/mtgpRUPfjRzkw8L/+/p
HyoxGTE=
      "]], LineBox[CompressedData["
1:eJw11QlMk2cYB/CvX1sUjwwjgjiDQXA4EMlG7QXlfVoopbSoME9WXEShTBni
AUxACSIQ8ACcICBOIpfFidcEFeY5x5yiTEXAicolKAuigqYUyvp1D2/SkKbl
3+d9fv+mDmFbgsNpiqKSTA/mb9OSzqUJs/WEMp+lMC+tP+iSvZ78XvRO0eau
Bv+OBOtqhZ5UVOw/f3KGH2yVTGkpjdGTgjrNtCMZMigqZI6eCK8p+xyWA9wa
XqjJvqknXfQ+3s6zEvjXlJbWryez5pCqBzpPmFWtMCWOkNCxpqMykRi8mTjJ
CBmJYYW2uolAG8GcEXI04eE+5++FkHOTCRwhQX+VNuxqEcBle2bAEaLLmDm9
bLMAOpnxOkbIYHvSkfi5ApjKxE0xkMe3l6l2dfGB58EcA1kgtElg1fMhNJsJ
NBD5gymJmSf4kM5cN81Ahupn6uIO8+EMM161gVRZTrf/M5sPrUxci4HkBA9a
Dx7iA8u8p1Fyi691qSnmg4uGCRwlce2nRPN/4UMwc92gUeLtpLD74TofEpnx
EkbJJk+rqOFWPpQxcaWjZJ6j5TeCYT403mPOKHnu07P4D2sBfGTWNzxKyvtz
XioEAvQYI83ZfMetGgF6jJGPcKCW3itAjzEiCYte1HBagB5jZM+Ge/a5bQL0
GCP9MK9ZNEmIHqb3dyc7lPCF6GEkVnufJFRqhehhJJmLFVJBkRA9jCQp8m8n
8f0JDyMpW+1aeYwtQg8j0bjFXAgSi9DDSGybtQr/bSL0GCcp+6xdY0+J0GOc
REH3hcYeEXqMk77bUbn+DmL0GCe2hZwT7aFi9DC9frW9Me2oGD3GiZVjVq/4
qRj+7y0FO9y4uZ/sJvpFgbo/w6k2xBO+NPtQ8E/awZLYYk8wr0tCgUdxTr77
C0/0ouDCffbczvleYL5uBAVlEUG/ZWm90I+C+/Fx25xPe4F53GwKQg7PyKv5
4IWeFCT2VrXwPSVgjrtEQdR3BkllqgR9KbibmGwzqVGC+6Hg6fquDyttvdGb
gjNrN5z8Kcwb98WCiILHcL3aG/1Z8HFVPvXM4A3m9XmwwCHldWivkmAfWND4
9Kyxs4CA+boaFojlBy4+6CPYDxa8rSsnLXMBzHFpLNg9pIbrcsC+sGBy9HiK
4xYA8/qqTZ/fwK5nFU58n1nwI6+55ttbAObxWlhwPHKz6usBwD6xINeQH5Zu
J0UPGtKEMUNr5FL0oOF2xpNJp7ZK0YOG1DbjuV0/S7FvNIh0n9k8vCtFDxr2
h9zZqNNLsX807GwWPeMslKEHDXu1CQ09q2TYRxpWTIvfHZguQw8alqy5Gi6p
kWE/aXi8cu1AzSsZetBgWVeVV2frgx40vHy9oket9EEPGi7LvtgeleiDHmxY
vHZqx+fVPujBhiSdRbumwwf7zIZj8W4OX83yRQ82PMvUbS9S+qKH6fnOaxVF
u33Rgw1X1rUVePzqix5scCzM42nf+KIHG2YfaosROMjRgw3h0Le8Yo0cPdgQ
tzyp+2KOHD3YsONejyLyjhw92MALSSm5RvuhBwfUx9zcr3r5oQcHFMVNrhHx
fujBgaaHTm8un/dDDw68T85rqBvwQw8OBGfZuUe7KtCDA3IvbeGjSAV6cEAz
2fXAQIUCPTiQSqTHb/Qo0IMDHjXvty1b4I8eHAhfzbtSFO6PHqb/L3+9pKLC
Hz04MOTqUrOjzx89OPDoVeYcS1clenABSjcGR0Qr0YMLb8IWhWafV6IHFxru
XAnI+KREDy5sLin3DJIEoAcXbOLz1w+mBqAHF/bElo9r7wagBxfORdRuqpup
Qg8uuFi9sBzQqNCDC0PdN1axK1XowYV6Z+q58Z0KPbjQfLCEdEvU6MGFdcnJ
7rVZavSwAOPwjdjEVjV6WICOp37Lcw5EDwtQLfU62BsXiB4W8LwqMuRIQyB4
kBVdh1UWMPF7/R8QDFq2
      "]]}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 4}, {0, 60}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0, 0}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.8113963138407717`*^9},
 CellLabel->"Out[11]=",ExpressionUUID->"74ec8834-63f0-48f3-b37c-7097b899c87c"]
}, Open  ]],

Cell["\<\
Create a graphics object of lines denoting the secular eigenfrequencies.\
\>", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"ba5135e1-2c59-491a-aa78-65a25046a98e"],

Cell["\<\
gin = Graphics[Map[Line[{{0,#},{4,#}}]&, gg]];
fin = Graphics[
Join[{Dashing[{0.01, 0.01}]},
     Map[Line[{{0,#},{4,#}}]&, -ff]]];\
\>", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[12]:=",ExpressionUUID->"04ee1c92-6e0e-4524-ad4e-cc637ddd2475"],

Cell["Display the plot with the eigenfrequencies.", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"c8e91a1b-2259-40cb-816b-efcaf106f07e"],

Cell[CellGroupData[{

Cell["Show[pin, gin, fin]", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[14]:=",ExpressionUUID->"34638f33-821b-4373-91cf-5384c2bcec6b"],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.007333333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQPWsmCOy07zFTVCx+/9heM6b/0FeNPfZrJty9KKr3
3H6nXOvrwB377H9d3t7Av/SV/ZICW67riw/Y+/Ws2sEe/s7+TeAOoIqD9h4d
Qt0HlT/amxiDwGF76UVKGxttP9tXi6xzf1h1xP7H9TtCs6u/2h/+qgG04ag9
Z/XdW7MefrcHGgY08bj9vweLqj8W/7IPAhkXeMJ+cqnKUgOLv/YQ9520/8GW
vmuDFIPDoyqQgafsPz6wfmm3i9EB4t4z9qdNrFj6G5gdCkHOKzhrvyiN455V
KasDxP3n7C+FN3imLWJ3YACDC/YLHPcW3RPlcoD454L95O0bdt55xOPg8RBk
wUX7L6UtbQVCAg4Q/1201zgiv92OSchhwiGQBy7Z850tP3o/XsQB4t/L9h9X
it6+HSPuAPbO9cv2yXWlOeU+0g4Q/1+x/3f/tcznRAUHeZBz5K7ay3MvW9BT
pOIANu7QVXvzZDvdpYLaDmlgcM3e7843t2krjR0g4XPdvqfz6O2sXQ4OzRd1
OC/nXLeH+MPPAQC9utIr
       "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQfTBxdUO/yi17BjDwc7Djur64wPaW/eqKw8c50twd
HlWJrHN/eMs+w60rkdXPyqHtdeAOudbb9j3vcw80rjFy0IrpP/RV4479b/Hw
fqVCPYdzZ0Dgjr1qw7rv28W0HQpsQQbetb//fbPbsU5NB5BpVSL37Ld1M0RG
cGo6AA0DmnjPvuFHRpW2paYD2LiY+/ZlARv27X2l6QBx1wP792pxlp/YtB2C
wBoe2O970X5drkXHYQnYggf2dmcsrIsS9Ry+aYBMeGCftebUkoogAwePh2AP
2L/b+DG1dK2hw6yZIPDQPrj9craFt7HDG5B3Xj+0N6uqX5BoaQr1/yP7tztF
z7zuMncAO6f/kf22rVe2WURZOUCMe2TfUC1XEXTG1sEYDB7bG8xbrifC7ejQ
Cg6fx/a8x9YxzD7k7AAyjev6Y3smcf/1mu7uDppgDz6xb2vIWiH1xduhNCw4
Vcz5CTz8AaBztKU=
       "]], 
      LineBox[{{0.8411725519888572, 60.}, {0.85, 58.869482463564125`}, {0.86, 
       59.34626183294532}, {0.8629617850360661, 60.}}], 
      LineBox[CompressedData["
1:eJw9kl9IU2EYxudYN8YMwUkWLboZ0zUKdo6bq/m+M3KGGE2pIGxFsQVFuVYw
OUUQsRlpM8zI04Qca9FFTgIjSxikUTdptYusIWH2b7FheP4tFkH7xkcPfHx3
P56H37vlWE+nV61SqQylR/5Qj2c//3YVVOXsxbx7Sh/KrYJHG9mkbW9HXdL1
masRwNDVt91d14bNlQtxv0OAYP/IoufmbjzhIxEglTn9t+X6LrwxIxu7BwUQ
89loV9aJT0s095QAvzacCyQiiMtcTYkowAP+/Zh/qRnXElylCKPp55EOtQMZ
C4kIqbuffFn/Djw8SIAiDP2um7yot2M4RwqKYLw0n/ComnCC1EuKEKvfumSp
suEHglsQoXV23zOv04oV5V0SzIc9G6eHG7G+mwAlmDNanVWaRuwkc90S/Ih+
j9cOsHiB1OMkSEWrp50NLN4juLgEE6eYhtuLDM69JpEgfGul9n6MQcVIgBJo
/+SPcL0MbiZz9TI433F2/iiDbaSeS4Zccf21NYcYPEtwfhkyhgq2w8vgHZ5E
BpPpTTF2hcFZuQwER/ULi/oJQ33IUEyvW+5Vs9SHAj9HfUOXT7LUhwLfxpuC
CZmlPhSwhVz9wfFG6kMBs/joJTNmpT4USJ8JHBj4YqM+FDi+zZQc4e3URwEe
m4c1UNxJfRQgmL+q01iQ+iiALrOnj3/VQn0UwDJz/mtgpRUPfjRzkw8L/+/p
HyoxGTE=
       "]], LineBox[CompressedData["
1:eJw11QlMk2cYB/CvX1sUjwwjgjiDQXA4EMlG7QXlfVoopbSoME9WXEShTBni
AUxACSIQ8ACcICBOIpfFidcEFeY5x5yiTEXAicolKAuigqYUyvp1D2/SkKbl
3+d9fv+mDmFbgsNpiqKSTA/mb9OSzqUJs/WEMp+lMC+tP+iSvZ78XvRO0eau
Bv+OBOtqhZ5UVOw/f3KGH2yVTGkpjdGTgjrNtCMZMigqZI6eCK8p+xyWA9wa
XqjJvqknXfQ+3s6zEvjXlJbWryez5pCqBzpPmFWtMCWOkNCxpqMykRi8mTjJ
CBmJYYW2uolAG8GcEXI04eE+5++FkHOTCRwhQX+VNuxqEcBle2bAEaLLmDm9
bLMAOpnxOkbIYHvSkfi5ApjKxE0xkMe3l6l2dfGB58EcA1kgtElg1fMhNJsJ
NBD5gymJmSf4kM5cN81Ahupn6uIO8+EMM161gVRZTrf/M5sPrUxci4HkBA9a
Dx7iA8u8p1Fyi691qSnmg4uGCRwlce2nRPN/4UMwc92gUeLtpLD74TofEpnx
EkbJJk+rqOFWPpQxcaWjZJ6j5TeCYT403mPOKHnu07P4D2sBfGTWNzxKyvtz
XioEAvQYI83ZfMetGgF6jJGPcKCW3itAjzEiCYte1HBagB5jZM+Ge/a5bQL0
GCP9MK9ZNEmIHqb3dyc7lPCF6GEkVnufJFRqhehhJJmLFVJBkRA9jCQp8m8n
8f0JDyMpW+1aeYwtQg8j0bjFXAgSi9DDSGybtQr/bSL0GCcp+6xdY0+J0GOc
REH3hcYeEXqMk77bUbn+DmL0GCe2hZwT7aFi9DC9frW9Me2oGD3GiZVjVq/4
qRj+7y0FO9y4uZ/sJvpFgbo/w6k2xBO+NPtQ8E/awZLYYk8wr0tCgUdxTr77
C0/0ouDCffbczvleYL5uBAVlEUG/ZWm90I+C+/Fx25xPe4F53GwKQg7PyKv5
4IWeFCT2VrXwPSVgjrtEQdR3BkllqgR9KbibmGwzqVGC+6Hg6fquDyttvdGb
gjNrN5z8Kcwb98WCiILHcL3aG/1Z8HFVPvXM4A3m9XmwwCHldWivkmAfWND4
9Kyxs4CA+boaFojlBy4+6CPYDxa8rSsnLXMBzHFpLNg9pIbrcsC+sGBy9HiK
4xYA8/qqTZ/fwK5nFU58n1nwI6+55ttbAObxWlhwPHKz6usBwD6xINeQH5Zu
J0UPGtKEMUNr5FL0oOF2xpNJp7ZK0YOG1DbjuV0/S7FvNIh0n9k8vCtFDxr2
h9zZqNNLsX807GwWPeMslKEHDXu1CQ09q2TYRxpWTIvfHZguQw8alqy5Gi6p
kWE/aXi8cu1AzSsZetBgWVeVV2frgx40vHy9oket9EEPGi7LvtgeleiDHmxY
vHZqx+fVPujBhiSdRbumwwf7zIZj8W4OX83yRQ82PMvUbS9S+qKH6fnOaxVF
u33Rgw1X1rUVePzqix5scCzM42nf+KIHG2YfaosROMjRgw3h0Le8Yo0cPdgQ
tzyp+2KOHD3YsONejyLyjhw92MALSSm5RvuhBwfUx9zcr3r5oQcHFMVNrhHx
fujBgaaHTm8un/dDDw68T85rqBvwQw8OBGfZuUe7KtCDA3IvbeGjSAV6cEAz
2fXAQIUCPTiQSqTHb/Qo0IMDHjXvty1b4I8eHAhfzbtSFO6PHqb/L3+9pKLC
Hz04MOTqUrOjzx89OPDoVeYcS1clenABSjcGR0Qr0YMLb8IWhWafV6IHFxru
XAnI+KREDy5sLin3DJIEoAcXbOLz1w+mBqAHF/bElo9r7wagBxfORdRuqpup
Qg8uuFi9sBzQqNCDC0PdN1axK1XowYV6Z+q58Z0KPbjQfLCEdEvU6MGFdcnJ
7rVZavSwAOPwjdjEVjV6WICOp37Lcw5EDwtQLfU62BsXiB4W8LwqMuRIQyB4
kBVdh1UWMPF7/R8QDFq2
       "]]}}, {{}, {}}}, {
    LineBox[{{0, 5.46326}, {4, 5.46326}}], 
    LineBox[{{0, 7.34474}, {4, 7.34474}}], 
    LineBox[{{0, 17.32832}, {4, 17.32832}}], 
    LineBox[{{0, 18.00233}, {4, 18.00233}}], 
    LineBox[{{0, 4.29591}, {4, 4.29591}}], 
    LineBox[{{0, 27.77406}, {4, 27.77406}}], 
    LineBox[{{0, 2.71931}, {4, 2.71931}}], 
    LineBox[{{0, 0.63332}, {4, 0.63332}}], 
    LineBox[{{0, -19.18225}, {4, -19.18225}}], 
    LineBox[{{0, 51.25222}, {4, 51.25222}}]}, 
   {Dashing[{0.01, 0.01}], LineBox[{{0, 5.21054}, {4, 5.21054}}], 
    LineBox[{{0, 6.5708}, {4, 6.5708}}], 
    LineBox[{{0, 18.74359}, {4, 18.74359}}], 
    LineBox[{{0, 17.63331}, {4, 17.63331}}], LineBox[{{0, 0.}, {4, 0.}}], 
    LineBox[{{0, 25.73355}, {4, 25.73355}}], 
    LineBox[{{0, 2.90266}, {4, 2.90266}}], 
    LineBox[{{0, 0.67752}, {4, 0.67752}}]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 4}, {0, 60}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0, 0}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.8113963138929663`*^9},
 CellLabel->"Out[14]=",ExpressionUUID->"7c09d380-99b5-4778-8ee8-d08f9f354258"]
}, Open  ]]
},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{917, 627},
WindowMargins->{{16, Automatic}, {Automatic, 244}},
PrivateNotebookOptions->{"VersionedStylesheet"->{"Default.nb"[8.] -> False}},
ShowCellLabel->True,
ShowCellTags->False,
FrontEndVersion->"12.1 for Mac OS X x86 (64-bit) (June 19, 2020)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"b0eb7993-f1d2-410f-9b1f-451674d9e365"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 110, 0, 67, "Section",ExpressionUUID->"4c583ca5-29ab-42df-b722-130c8619e95e"],
Cell[671, 22, 291, 8, 49, "Text",ExpressionUUID->"23a1f66f-3303-412c-995e-0cd8bd4183f4"],
Cell[965, 32, 287, 8, 102, "Input",ExpressionUUID->"12842ddc-be9a-457a-ae8c-0669623c27b0"],
Cell[1255, 42, 477, 14, 76, "Text",ExpressionUUID->"2b3480b4-09f3-4ff8-ab9e-88093ccdc961"],
Cell[1735, 58, 929, 26, 426, "Input",ExpressionUUID->"dc51d451-5bfa-4a04-b0e2-966b00cfcebf"],
Cell[2667, 86, 221, 6, 53, "Text",ExpressionUUID->"42a8c10d-d498-4489-8574-9571b678f5d6"],
Cell[2891, 94, 204, 5, 48, "Input",ExpressionUUID->"71aafb30-1a9d-43a7-890c-c7e98dd0e484"],
Cell[3098, 101, 176, 3, 53, "Text",ExpressionUUID->"ea41f3db-d17e-4ca9-9c9d-4b458e80023d"],
Cell[CellGroupData[{
Cell[3299, 108, 219, 6, 66, "Input",ExpressionUUID->"a97ca0a4-743e-4e94-b155-a147f337f81e"],
Cell[3521, 116, 6237, 117, 250, "Output",ExpressionUUID->"6765730f-34c8-4286-9d38-54f0248324d5"]
}, Open  ]],
Cell[9773, 236, 205, 5, 53, "Text",ExpressionUUID->"833daf2b-3d5a-4992-91e2-b97366f85591"],
Cell[9981, 243, 341, 7, 84, "Input",ExpressionUUID->"5c22d214-655a-445d-916a-6b3da546b41f"],
Cell[10325, 252, 206, 5, 53, "Text",ExpressionUUID->"b807715f-59bb-4418-ba6a-d9752e9c790e"],
Cell[10534, 259, 270, 7, 84, "Input",ExpressionUUID->"6f9bce32-af29-42b1-a369-bec1da83d2db"],
Cell[10807, 268, 169, 3, 53, "Text",ExpressionUUID->"55fb4b69-e04b-43fe-9a16-642eea83637e"],
Cell[CellGroupData[{
Cell[11001, 275, 149, 2, 30, "Input",ExpressionUUID->"c27abf52-0b6f-496b-8207-d8b6a3bd63d1"],
Cell[11153, 279, 7094, 133, 250, "Output",ExpressionUUID->"b1fd5258-ac05-493d-8173-144cd80a1f2d"]
}, Open  ]],
Cell[18262, 415, 242, 6, 53, "Text",ExpressionUUID->"faf53744-1524-4491-862a-40ad8ebaf6ed"],
Cell[18507, 423, 210, 5, 48, "Input",ExpressionUUID->"222c82f2-9444-4f13-bece-f7294e530306"],
Cell[18720, 430, 173, 3, 53, "Text",ExpressionUUID->"40d611ae-cfdb-440a-8da0-66352d0283e2"],
Cell[CellGroupData[{
Cell[18918, 437, 224, 6, 66, "Input",ExpressionUUID->"261f2a88-2d15-4be8-ad63-6dc582256655"],
Cell[19145, 445, 5227, 102, 252, "Output",ExpressionUUID->"74ec8834-63f0-48f3-b37c-7097b899c87c"]
}, Open  ]],
Cell[24387, 550, 206, 5, 53, "Text",ExpressionUUID->"ba5135e1-2c59-491a-aa78-65a25046a98e"],
Cell[24596, 557, 267, 7, 84, "Input",ExpressionUUID->"04ee1c92-6e0e-4524-ad4e-cc637ddd2475"],
Cell[24866, 566, 169, 3, 53, "Text",ExpressionUUID->"c8e91a1b-2259-40cb-816b-efcaf106f07e"],
Cell[CellGroupData[{
Cell[25060, 573, 147, 2, 30, "Input",ExpressionUUID->"34638f33-821b-4373-91cf-5384c2bcec6b"],
Cell[25210, 577, 6063, 120, 275, "Output",ExpressionUUID->"7c09d380-99b5-4778-8ee8-d08f9f354258"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

